#ifndef NT2_INCLUDE_CONSTANTS_INT_SPLAT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INT_SPLAT_HPP_INCLUDED

#include <nt2/constant/include/constants/int_splat.hpp>

#endif
